@@ -49,6 +49,7 @@ from google.cloud.bigquery.external_config import BigtableColumn
 from google.cloud.bigquery.external_config import CSVOptions
 from google.cloud.bigquery.external_config import GoogleSheetsOptions
 from google.cloud.bigquery.external_config import ExternalSourceFormat
+from google.cloud.bigquery.external_config import HivePartitioningOptions
 from google.cloud.bigquery.format_options import AvroOptions
 from google.cloud.bigquery.format_options import ParquetOptions
 from google.cloud.bigquery.job.base import SessionInfo
@@ -161,6 +162,7 @@ __all__ = [
     "DmlStats",
     "CSVOptions",
     "GoogleSheetsOptions",
+    "HivePartitioningOptions",
     "ParquetOptions",
     "ScriptOptions",
     "TransactionInfo",
